@@ -1,14 +1,26 @@
+import logging
 import os
+import shutil
+from pathlib import Path
 from typing import Optional
 
 from jsoncfg.value_mappers import require_string
+
+from peek_platform import PeekPlatformConfig
 from peek_plugin_base.PluginCommonEntryHookABC import PluginCommonEntryHookABC
-from peek_plugin_base.client.PeekClientPlatformHookABC import PeekClientPlatformHookABC
+from peek_plugin_base.client.PeekClientPlatformHookABC import (
+    PeekClientPlatformHookABC,
+)
+
+logger = logging.getLogger(__name__)
 
 
 class PluginClientEntryHookABC(PluginCommonEntryHookABC):
     def __init__(
-        self, pluginName: str, pluginRootDir: str, platform: PeekClientPlatformHookABC
+        self,
+        pluginName: str,
+        pluginRootDir: str,
+        platform: PeekClientPlatformHookABC,
     ):
         PluginCommonEntryHookABC.__init__(
             self, pluginName=pluginName, pluginRootDir=pluginRootDir
@@ -44,3 +56,10 @@ class PluginClientEntryHookABC(PluginCommonEntryHookABC):
         if not os.path.isdir(dir):
             raise NotADirectoryError(dir)
         return dir
+
+    @property
+    def platformConfig(self):
+        return PeekPlatformConfig.config
+
+    def copyFolder(self, srcDir: Path, dstDir: Path):
+        shutil.copytree(srcDir, dstDir, dirs_exist_ok=True)
