@@ -1,8 +1,12 @@
 import importlib
 import logging
 
-from celery.signals import worker_process_init, worker_process_shutdown, worker_init, \
-    task_postrun
+from celery.signals import (
+    worker_process_init,
+    worker_process_shutdown,
+    worker_init,
+    task_postrun,
+)
 
 from peek_plugin_base.worker import CeleryDbConn
 from peek_plugin_base.worker.CeleryDbConn import getDbSession
@@ -25,21 +29,22 @@ def initWorkerConnString(sender, **kwargs):
 
 @worker_process_init.connect
 def initWorkerProcessDbConn(**kwargs):
-    logger.debug('Creating unique database connection for worker process')
+    logger.debug("Creating unique database connection for worker process")
 
     # The next call to CeleryDbConn.dbEngine property will create a new engine
     # with this connection string
     from peek_plugin_base.worker import CeleryDbConn
+
     CeleryDbConn = importlib.reload(CeleryDbConn)
 
     CeleryDbConn._dbConnectString = __WorkerInit.dbConnectString
     CeleryDbConn._dbEngineArgs = __WorkerInit.dbEngineArgs
-    logger.info('Created unique database connection for worker process')
+    logger.info("Created unique database connection for worker process")
 
 
 @worker_process_shutdown.connect
 def shutdownWorkerProcessDbConn(**kwargs):
-    logger.debug('Closing database connectionn for worker.')
+    logger.debug("Closing database connectionn for worker.")
 
     if CeleryDbConn.__ScopedSession:
         getDbSession()  # Ensure we have a session maker
@@ -48,7 +53,7 @@ def shutdownWorkerProcessDbConn(**kwargs):
     if CeleryDbConn.__dbEngine:
         CeleryDbConn.__dbEngine.dispose()
 
-    logger.info('Closed database connectionn for worker.')
+    logger.info("Closed database connectionn for worker.")
 
 
 @task_postrun.connect
